docs = [
    {
        "path": "../docs/rag",
    },
    {
        "path": "../docs/rag/build/",
    },
    {
        "path": "../docs/rag/build/one.md",
    },
    {
        "path": "../docs/rag/query/",
    },
    {
        "path": "../docs/rag/query/one.md",
    },
]
